summaryrefslogtreecommitdiffstats
path: root/libtdegames/highscore/kexthighscore_item.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
commitc0f375feba0103bed2bac1b1f05e76e9ae28fa89 (patch)
tree9c30a9097d650343df41d867f0e008769529eb08 /libtdegames/highscore/kexthighscore_item.h
parent0e2b76239f354a9eead0b4e37d86d390ec57ffa9 (diff)
downloadtdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.tar.gz
tdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'libtdegames/highscore/kexthighscore_item.h')
-rw-r--r--libtdegames/highscore/kexthighscore_item.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libtdegames/highscore/kexthighscore_item.h b/libtdegames/highscore/kexthighscore_item.h
index b32f32e7..8379433b 100644
--- a/libtdegames/highscore/kexthighscore_item.h
+++ b/libtdegames/highscore/kexthighscore_item.h
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* Be sure to cast the value to the required type (for e.g. with uint).
* @param label the label corresponding to the item. If empty, the item
* is not shown.
* @param tqalignment the tqalignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,
- const TQString &label = TQString(), int tqalignment = TQt::AlignRight);
+ const TQString &label = TQString(), int alignment = TQt::AlignRight);
virtual ~Item();
@@ -114,9 +114,9 @@ class KDE_EXPORT Item
TQString label() const { return _label; }
/**
- * @return the tqalignment.
+ * @return the alignment.
*/
- int tqalignment() const { return _tqalignment; }
+ int alignment() const { return _alignment; }
/**
* Set default value.
@@ -149,7 +149,7 @@ class KDE_EXPORT Item
private:
TQVariant _default;
TQString _label;
- int _tqalignment;
+ int _alignment;
Format _format;
Special _special;
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* @param label the label corresponding to the item. If empty, the item
* is not shown.
- * @param tqalignment the tqalignment of the item.
+ * @param alignment the alignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,